@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use Test::Trap ();        # load as early as possible to override CORE::exit
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
-use parent 'Exporter';
+use base qw(Exporter);
 
 use Carp ();
 use Exporter ();
@@ -19,7 +19,7 @@ our $Debug = $ENV{TEST_SPEC_DEBUG} || 0;
 
 our @EXPORT      = qw(runtests
                       describe xdescribe context xcontext it xit they xthey
-                      before after around yield spec_helper
+                      before after spec_helper
                       *TODO share shared_examples_for it_should_behave_like );
 our @EXPORT_OK   = ( @EXPORT, qw(DEFINITION_PHASE EXECUTION_PHASE $Debug) );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK,
@@ -70,7 +70,7 @@ sub import {
 
   eval qq{
     package $callpkg;
-    use parent 'Test::Spec';
+    use base 'Test::Spec';
     # allow Test::Spec usage errors to be reported via Carp
     our \@CARP_NOT = qw($callpkg);
   };
@@ -142,9 +142,10 @@ sub builder {
 sub _pick_tests {
   my ($class,@matchers) = @_;
   my @tests = $class->tests;
-  for my $pattern (@matchers) {
-    @tests = grep { $_->name =~ /$pattern/i } @tests;
-  }
+
+  my $pattern = join("|", @matchers);
+  @tests = grep { $_->name =~ /$pattern/i } @tests;
+
   return @tests;
 }
 
@@ -215,22 +216,6 @@ sub describe(@) {
   });
 }
 
-# around CODE
-sub around(&) {
-  my $package = caller;
-  my $code = pop;
-  if (ref($code) ne 'CODE') {
-    Carp::croak "expected subroutine reference as last argument";
-  }
-  my $context = _autovivify_context($package);
-  push @{ $context->around_blocks }, { code => $code };
-}
-
-# yield
-sub yield() {
-  $Test::Spec::Context::yield->();
-}
-
 # make context() an alias for describe()
 sub context(@);
 BEGIN { *context = \&describe }
@@ -747,27 +732,6 @@ respectively.  The default is "each".
 
 C<after "all"> blocks run I<after> C<after "each"> blocks.
 
-=item around CODE
-
-Defines code to be run around tests in the current describe block are
-run. This code must call C<yield>..
-
-  our $var = 0;
-
-  describe "Something" => sub {
-    around {
-      local $var = 1;
-      yield;
-    };
-
-    it "should have localized var" => sub {
-      is $var, 1;
-    };
-  };
-
-=item yield
-
-Runs examples in context of C<around> block.
 
 =item shared_examples_for DESCRIPTION => CODE
 
